#ifndef NT2_INCLUDE_FUNCTIONS_MAP_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MAP_HPP_INCLUDED

#include <nt2/operator/include/functions/map.hpp>

#endif
